@@ -104,7 +104,7 @@ push_packages <- local({
 
   canonize_arch <- function(platform) {
     arch <- strsplit(platform, "-", fixed = TRUE)[[1]][1]
-    c("aarch64" = "arm64", "x86_64" = "amd64")[[arch]]
+    c("aarch64" = "arm64", "x86_64" = "amd64", "arm64" = "arm64", "amd64" = "amd64")[[arch]]
   }
 
   canonize_os <- function(platform) {
@@ -641,6 +641,14 @@ create_pak_repo <- local({
   # - darwin17.0/x86_64
   # - darwin20/aarch64
   # - mingw32/x86_64
+  # - freebsd15.0/x86_64
+  # - freebsd14.1/x86_64
+  # - freebsd13.3/x86_64
+  # - openbsd7.6/x86_64
+  # - openbsd7.5/x86_64
+  # - openbsd7.4/x86_64
+  # - netbsd/x86_64
+  # - dragonfly6.4/x86_64
 
   # ## New form of the install command will use these repo URL and paths:
   # ```
@@ -658,6 +666,22 @@ create_pak_repo <- local({
   #      mingw32/x86_64
   # win.binary/mingw32/i386 + /bin/windows/contrib/4.1 ->
   #      mingw32/x86_64
+  # source/freebsd15.0/amd64 + /src/contrib ->
+  #      freebsd15.0/x86_64
+  # source/freebsd14.1/amd64 + /src/contrib ->
+  #      freebsd14.1/x86_64
+  # source/freebsd13.3/amd64 + /src/contrib ->
+  #      freebsd13.3/x86_64
+  # source/openbsd7.6/x86_64 + /src/contrib ->
+  #      openbsd7.6/x86_64
+  # source/openbsd7.5/x86_64 + /src/contrib ->
+  #      openbsd7.5/x86_64
+  # source/openbsd7.4/x86_64 + /src/contrib ->
+  #      openbsd7.4/x86_64
+  # source/netbsd/x86_64 + /src/contrib ->
+  #      netbsd/x86_64
+  # source/dragonfly6.4/x86_64 + /src/contrib ->
+  #      dragonfly6.4/x86_64
   # ```
   #
   # Unsupported platforms will get a non-existant path, e.g. homebrew R
@@ -706,6 +730,29 @@ create_pak_repo <- local({
     "source/linux-dietlibc/aarch64/src/contrib" = "../../../../../linux/aarch64",
     "source/linux-unknown/aarch64/src/contrib" = "../../../../../linux/aarch64",
 
+    "source/freebsd15.6/amd64/src/contrib" = "../../../../../freebsd15.6/x86_64",
+    "source/freebsd15.5/amd64/src/contrib" = "../../../../../freebsd15.5/x86_64",
+    "source/freebsd15.4/amd64/src/contrib" = "../../../../../freebsd15.4/x86_64",
+    "source/freebsd15.3/amd64/src/contrib" = "../../../../../freebsd15.3/x86_64",
+    "source/freebsd15.2/amd64/src/contrib" = "../../../../../freebsd15.2/x86_64",
+    "source/freebsd15.1/amd64/src/contrib" = "../../../../../freebsd15.1/x86_64",
+    "source/freebsd15.0/amd64/src/contrib" = "../../../../../freebsd15.0/x86_64",
+    "source/freebsd14.6/amd64/src/contrib" = "../../../../../freebsd14.6/x86_64",
+    "source/freebsd14.5/amd64/src/contrib" = "../../../../../freebsd14.5/x86_64",
+    "source/freebsd14.4/amd64/src/contrib" = "../../../../../freebsd14.4/x86_64",
+    "source/freebsd14.3/amd64/src/contrib" = "../../../../../freebsd14.3/x86_64",
+    "source/freebsd14.2/amd64/src/contrib" = "../../../../../freebsd14.2/x86_64",
+    "source/freebsd14.1/amd64/src/contrib" = "../../../../../freebsd14.1/x86_64",
+    "source/freebsd13.6/amd64/src/contrib" = "../../../../../freebsd13.6/x86_64",
+    "source/freebsd13.5/amd64/src/contrib" = "../../../../../freebsd13.5/x86_64",
+    "source/freebsd13.4/amd64/src/contrib" = "../../../../../freebsd13.4/x86_64",
+    "source/freebsd13.3/amd64/src/contrib" = "../../../../../freebsd13.3/x86_64",
+    "source/openbsd7.6/x86_64/src/contrib" = "../../../../../openbsd7.6/x86_64",
+    "source/openbsd7.5/x86_64/src/contrib" = "../../../../../openbsd7.5/x86_64",
+    "source/openbsd7.4/x86_64/src/contrib" = "../../../../../openbsd7.4/x86_64",
+    "source/netbsd/x86_64/src/contrib" = "../../../../../netbsd/x86_64",
+    "source/dragonfly6.4/x86_64/src/contrib" = "../../../../../dragonfly6.4/x86_64",
+
     # Map the pkgType/os/arch form binaries of other OSes to the right place.
     "win.binary/mingw32/x86_64/src/contrib" = "../../../../../mingw32/x86_64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/src/contrib" = "../../../../../darwin20/aarch64",
